#!/usr/bin/env python
# -*- coding: utf-8 -*-

# IDEA: use the plugin sequentially...
# This version is inspired by programs:
# "GMIC - faves" http://gmic.sourceforge.net/reference.shtml
# "Gimpscripter by bootchk" https://github.com/bootchk/gimpscripter
# "Plugin text-to-image for Gimp" http://nikita.melnichenko.name/projects/gimp-text-to-image/?lang=en

# Installation: put the file into ~/.gimp-2.n/plug-ins, set executable bit on it.


from gimpfu import *
import os

def python_fu_text_to_logo(text, margin, font, just, font_size, text_color, background_color, background_opacity, flatten, gmic):
	# set foreground color
	gimp.set_foreground(text_color)
	
	# set background color
	gimp.set_background(background_color)

	# create image: width, height, type
	image = gimp.Image(font_size, font_size, RGB)

	# create layer with text and add it to the image: image, drawable, x, y, text, border, antialias, size, size_type, fontname
	text_layer = pdb.gimp_text_fontname(image, None, 0, 0, text, margin, 1, font_size, PIXELS, font)

	# justification:
	pdb.gimp_text_layer_set_justification (text_layer, just)
	
	# resize image to layer content
	pdb.gimp_image_resize_to_layers(image)
	    
	# create layer: image, width, height, type, name, opacity, mode
	layer = gimp.Layer(image, "background", image.width, image.height, RGBA_IMAGE, background_opacity, NORMAL_MODE)
	
	# append layer to the image
	image.add_layer(layer, 0)
	
	# fill layer with color
	layer.fill(BACKGROUND_FILL)
	layer = image.merge_visible_layers(CLIP_TO_IMAGE)

	gimp_copy = layer.copy(0)
	image.add_layer(gimp_copy, 0)
	gimp_copy.name = "Efekt GMIC"
	
	if gmic==0: gimp.pdb.plug_in_gmic( image, layer, 1, '-gimp_skeleton_preview 1,0,0,1,0', run_mode=RUN_NONINTERACTIVE), gimp.pdb.plug_in_gmic( image, layer, 1, '-gimp_crayongraffiti2_preview 300,50,1,0.4,12,1,2,2,0', run_mode=RUN_NONINTERACTIVE)
	if gmic==1: gimp.pdb.plug_in_gmic( image, layer, 1, '-gimp_light_relief 0.3,0.2,0.2,0,1,0.5,0.5,5,0.5,0,0', run_mode=RUN_NONINTERACTIVE), gimp.pdb.plug_in_gmic( image, layer, 1, '-gtutor_hairlock_preview 0.5,0.5,0.5,255,255,0,255,0.5,45,0.5,0.5,0', run_mode=RUN_NONINTERACTIVE)
	if gmic==2: gimp.pdb.plug_in_gmic( image, layer, 1, '-gimp_light_relief 0.3,0.2,0.2,0,1,0.5,0.5,5,0.5,0,0', run_mode=RUN_NONINTERACTIVE), gimp.pdb.plug_in_gmic( image, layer, 1, '-ripple 10,20,2,0,0', run_mode=RUN_NONINTERACTIVE)
	if gmic==3: gimp.pdb.plug_in_gmic( image, layer, 1, '-deform 5', run_mode=RUN_NONINTERACTIVE), gimp.pdb.plug_in_gmic( image, layer, 1, '-gtutor_hairlock_preview 0.5,0.5,0.5,255,255,0,255,0.5,45,0.5,0.5,0', run_mode=RUN_NONINTERACTIVE)
	if gmic==4: gimp.pdb.plug_in_gmic( image, layer, 1, '-gimp_metallicstencils_preview 0,0', run_mode=RUN_NONINTERACTIVE), gimp.pdb.plug_in_gmic( image, layer, 1, '-gimp_turbulence 128,6,4,0,4', run_mode=RUN_NONINTERACTIVE)
	if gmic==5: gimp.pdb.plug_in_gmic( image, layer, 1, '-gimp_textured_glass_preview 40,40,1,1,0,2,0,0', run_mode=RUN_NONINTERACTIVE), gimp.pdb.plug_in_gmic( image, layer, 1, '-samj_CeKoaSa_007_preview 1,0,10,10,300,5,30,0,0', run_mode=RUN_NONINTERACTIVE)
	if gmic==6: gimp.pdb.plug_in_gmic( image, layer, 1, '-gimp_textured_glass_preview 40,40,1,1,0,2,0,0', run_mode=RUN_NONINTERACTIVE), gimp.pdb.plug_in_gmic( image, layer, 1, '-gimp_light_relief 0.3,0.2,0.2,0,1,0.5,0.5,5,0.5,0,0', run_mode=RUN_NONINTERACTIVE)	
	
	# create layer: image, width, height, type, name, opacity, mode
	layer = gimp.Layer(image, "Tło", image.width, image.height, RGBA_IMAGE, 100, NORMAL_MODE)
	
	# append layer to the image
	image.add_layer(layer, 1)
	layer.fill( 1)
	
	# merge all layers
	if flatten:
	    image.merge_visible_layers(CLIP_TO_IMAGE)

	# display results
	try:
		gimp.Display(image)
	except:
		pass

register(
	"python_fu_text_to_gmic_logo_pl",
	"Tworzenie LOGO z użyciem G'MIC [V-0.1]",
	"Creates logo with specified text and G'mic",
	"MareoQ",
	"MrQ",
	"2014",
	"Gmic Logo PL...",
	"",
	[
		(PF_TEXT, 	"text", ("Tekst:"), "P F U G"),
		(PF_SLIDER, "margin", "Dodaj marginesy (px):", 50, (0, 500, 1)),
		(PF_FONT, "font", "Czcionka:", "Arial"),
		(PF_OPTION, "just",   "Rozmieszczenie:", 2, ["Wyrównanie do lewej","Wyrównanie do prawej","Wyśrodkowanie"]),
		(PF_INT, "font_size", "Rozmiar czcionki (px)", 150),
		(PF_COLOR, "text_color", "Kolor tekstu", (42, 133, 55)),
		(PF_COLOR, "background_color", "Kolor tła", (0, 0, 0)),
		(PF_SLIDER, "background_opacity", "Krycie tła", 50, (0, 100, 1)),
		(PF_BOOL,  "flatten",      "Połączyć warstwy ?", False),
		(PF_OPTION,   "gmic", "Polecenie Gmic:", 0, ["Skeleton + Black crayon graffiti","Relief light + Hair lock","Relief light + Ripple","Deform + Hair lock","Metallic stencils + Turbulence","Textured Glass + Samji CeKoaSa_007","Textured Glass + Relief light" ]),
	],
	[],
	python_fu_text_to_logo,
	menu="<Image>/File/Create/Logos",
	)

main()

